@@ -26,6 +26,9 @@ case $DPKG_ARCH in
 	hppa)
 		echo parisc
 		;; 
+	sparc64)
+		echo sparc
+		;; 
 	*) 
 		echo  $DPKG_ARCH
 		;;
