@@ -1,7 +1,15 @@
 #!/bin/bash --
 
 set -e
-. ../jh_lib.sh
+_DIR=`pwd`
+. ../jh_lib.sh.in
+
+run_jh_manifest()
+{
+    cd ..
+    ./jh_manifest "$@"
+    cd "$_DIR"
+}
 
 # checkmanifest <source> <correct result> [parameters...]
 checkmanifest()
@@ -13,7 +21,7 @@ checkmanifest()
 	shift
 	touch foo
 	jar cfm test.jar $source foo
-	../jh_manifest "$@" test.jar
+	run_jh_manifest "$@" "$_DIR/test.jar"
 	jar xf test.jar META-INF/MANIFEST.MF
 	if ! diff -u $verify META-INF/MANIFEST.MF > test.diff; then
 		error=1
